durationtools.duration_token_to_big_endian_list_of_assignable_duration_pairs
============================================================================

.. autofunction:: abjad.tools.durationtools.duration_token_to_big_endian_list_of_assignable_duration_pairs.duration_token_to_big_endian_list_of_assignable_duration_pairs
